com.github.cmd-mov.clj-elan.core


add-annotation-to-tierclj

(add-annotation-to-tier doc tier-id new-annotation)

Adds a new annotation to list of annotations of tier with given ID.

Adds a new annotation to list of annotations of tier with given ID.
raw docstring

add-cvclj

(add-cv doc cv)

Adds a new controlled vocabulary

Adds a new controlled vocabulary
raw docstring

add-dataset-to-docclj

(add-dataset-to-doc doc ds)

Adds a dataset as annotations in an ELAN document.

Adds a dataset as annotations in an ELAN document.
raw docstring

add-tierclj

(add-tier doc new-tier)

Adds a new tier to document

Adds a new tier to document
raw docstring

add-time-slotclj

(add-time-slot doc new-time-slot)

Adds a time slot to document.

Adds a time slot to document.
raw docstring

annotationclj

(annotation doc annotation-id)

Returns annotation with target ID.

Returns annotation with target ID.
raw docstring

annotation-end-time-refclj

(annotation-end-time-ref doc annotation-id)

Returns the end time reference of annotation with a target ID.

Returns the end time reference of annotation with a target ID.
raw docstring

annotation-idsclj

(annotation-ids doc)

Returns a vector of all annotation IDs in documents

Returns a vector of all annotation IDs in documents
raw docstring

annotation-start-time-refclj

(annotation-start-time-ref doc annotation-id)

Returns the start time reference of annotation with a target ID.

Returns the start time reference of annotation with a target ID.
raw docstring

annotation-textclj

(annotation-text doc annotation-id)

Returns text of annotation with target ID.

Returns text of annotation with target ID.
raw docstring

assert-is-annotation-id!clj

(assert-is-annotation-id! annotation-id)

assert-is-time-slot-id!clj

(assert-is-time-slot-id! time-slot-id)

Checks if input is formatted as a time slot.

Checks if input is formatted as a time slot.
raw docstring

assign-agreementclj

(assign-agreement all agree disagree select-annotation-when-agree tau)

Assigns agreement between two annotators by comparing subsequent entries in a dataset. The dataset should be the concatenation of the two annotator's datasets, ordered by time.

Assigns agreement between two annotators by comparing subsequent entries in a dataset.
The dataset should be the concatenation of the two annotator's datasets, ordered by time.
raw docstring

change-tier-typeclj

(change-tier-type doc tier-id new-type)

Changes the linguistic type ref of tier

Changes the linguistic type ref of tier
raw docstring

copy-cvclj

(copy-cv doc-from doc-to cv-id)

Copies a controlled vocabulary with a given ID from one document to another

Copies a controlled vocabulary with a given ID from one document to another
raw docstring

copy-tier-annotationsclj

(copy-tier-annotations doc-from tier-id-from doc-to tier-id-to)

Copies all annotations of a tier with an ID tier-id-from from doc-from to tier in ID tier-id-to in doc-to.

Copies all annotations of a tier with an ID tier-id-from from doc-from to tier in ID tier-id-to in doc-to. 
raw docstring

copy-tier-between-filesclj

(copy-tier-between-files doc1 doc2 tier-id)

Copy a tier with a given ID from one document to another

Copy a tier with a given ID from one document to another
raw docstring

cvclj

(cv doc cv-id)

Returns a controlled vocabulary by ID

Returns a controlled vocabulary by ID
raw docstring

cv-idsclj

(cv-ids doc)

Returns all controlled vocabulary ids

Returns all controlled vocabulary ids
raw docstring

cv-summaryclj

(cv-summary doc cv-id)

Summarizes control vocabulary, including associated tiers and number of entries

Summarizes control vocabulary, including associated tiers and number of entries
raw docstring

cv-vocab-with-idsclj

(cv-vocab-with-ids doc cv-id)

Returns a list of all controlled vocabulary entries and their associated unique identifiers

Returns a list of all controlled vocabulary entries and their associated unique identifiers
raw docstring

cvsclj

(cvs doc)

Returns all controlled vocabularies

Returns all controlled vocabularies
raw docstring

dataset-annotations-equal?clj

(dataset-annotations-equal? annotation-1 annotation-2 tau)

Checks if two annotations are equal, that is, with the same content and time intervals.

Checks if two annotations are equal, that is, with the same content and time intervals.
raw docstring

doc-summaryclj

(doc-summary doc)

Provides a summary of the document, including video file, controlled vocabularies, tiers, and number of annotations.

Provides a summary of the document, including video file, controlled vocabularies, tiers, and number of annotations.
raw docstring

flatten-annotationclj

(flatten-annotation annotation)

Changes the XML representation of an annotation to a flat map.

Changes the XML representation of an annotation to a flat map.
raw docstring

(header doc)

Returns the ELAN header

Returns the ELAN header
raw docstring

last-annotation-idclj

(last-annotation-id doc)

Returns the last annotation ID in the document

Returns the last annotation ID in the document
raw docstring

last-time-slot-idclj

(last-time-slot-id doc)

Returns last time slot ID in document.

Returns last time slot ID in document.
raw docstring

linguistic-typeclj

(linguistic-type doc linguistic-type-id)

Returns a linguistic type with a given ID

Returns a linguistic type with a given ID
raw docstring

linguistic-type-cvclj

(linguistic-type-cv doc linguistic-type-id)

Returns the controlled vocabulary id of a linguistic type with a given ID

Returns the controlled vocabulary id of a linguistic type with a given ID
raw docstring

linguistic-type-idsclj

(linguistic-type-ids doc)

Returns all linguistic type IDs

Returns all linguistic type IDs
raw docstring

linguistic-typesclj

(linguistic-types doc)

Returns all linguistic types

Returns all linguistic types
raw docstring

media-descriptorclj

(media-descriptor doc)

Returns the ELAN media descriptor

Returns the ELAN media descriptor
raw docstring

read-eafclj

(read-eaf filename)

Parses an ELAN .eaf XML file from the given filename into a standard Clojure structure.

Parses an ELAN .eaf XML file from the given filename into a standard Clojure structure.
raw docstring

remove-annotationclj

(remove-annotation doc annotation-id)

Removes annotation with target ID from document.

Removes annotation with target ID from document.
raw docstring

remove-cvclj

(remove-cv doc cv-id)

Removes a controlled vocabulary by ID

Removes a controlled vocabulary by ID
raw docstring

remove-tierclj

(remove-tier doc tier-id)

Removes tier from document

Removes tier from document
raw docstring

remove-tier-annotationsclj

(remove-tier-annotations doc tier-id)

Removes all annotations of a tier

Removes all annotations of a tier
raw docstring

remove-time-slotclj

(remove-time-slot doc time-slot-id)

Removes a time slot with a given ID.

Removes a time slot with a given ID.
raw docstring

rename-tierclj

(rename-tier doc tier-id new-tier-id)

Changes tier ID of a tier with a given tier ID

Changes tier ID of a tier with a given tier ID
raw docstring

replace-annotation-end-time-refclj

(replace-annotation-end-time-ref doc annotation-id new-ref)

Replaces the end time reference of annotation with a target ID.

Replaces the end time reference of annotation with a target ID.
raw docstring

replace-annotation-idclj

(replace-annotation-id doc annotation-id new-id)

Replaces annotation ID with a new ID

Replaces annotation ID with a new ID
raw docstring

replace-annotation-start-time-refclj

(replace-annotation-start-time-ref doc annotation-id new-ref)

Replaces the start time reference of annotation with a target ID.

Replaces the start time reference of annotation with a target ID.
raw docstring

replace-annotation-textclj

(replace-annotation-text doc annotation-id new-text)

Replaces the text of annotation with a target ID.

Replaces the text of annotation with a target ID.
raw docstring

replace-prefixclj

(replace-prefix doc old-prefix new-prefix)

Replaces all annotations with a give prefix with a new prefix.

Replaces all annotations with a give prefix with a new prefix.
raw docstring

replace-tierclj

(replace-tier doc tier-id new-tier)

Replaces a tier with a given id with a new tier

Replaces a tier with a given id with a new tier
raw docstring

replace-tier-annotationsclj

(replace-tier-annotations doc tier-id new-annotations)

Replaces all annotations with a new list of annotations of a tier with a given ID

Replaces all annotations with a new list of annotations of a tier with a given ID
raw docstring

replace-time-orderclj

(replace-time-order doc new-time-order)

Replaces time order of document with a new time order.

Replaces time order of document with a new time order.
raw docstring

replace-time-slotsclj

(replace-time-slots doc new-time-slots)

Replaces time slots in document with new time slots.

Replaces time slots in document with new time slots.
raw docstring

replace-video-rel-urlclj

(replace-video-rel-url doc new-rel-url)

Replaces the relative path to the video

Replaces the relative path to the video
raw docstring

replace-video-urlclj

(replace-video-url doc new-url)

Replaces the absolute path to the video

Replaces the absolute path to the video
raw docstring

same-intervals?clj

(same-intervals? t-start-1 t-end-1 t-start-2 t-end-2 tau)

Checks if two intervals are equal within a tolerance tau.

Checks if two intervals are equal within a tolerance tau.
raw docstring

selected-time-slotsclj

(selected-time-slots doc time-slot-ids)

Returns all time slots that match a given vector of time slot IDs.

Returns all time slots that match a given vector of time slot IDs.
raw docstring

tierclj

(tier doc tier-id)

Returns a tier with a given tier ID

Returns a tier with a given tier ID
raw docstring

tier-agreementclj

(tier-agreement doc1 doc2 tier-id tau)

Compares the annotations of two annotators.

Compares the annotations of two annotators.
raw docstring

tier-annotationsclj

(tier-annotations doc tier-id)

Returns a list of all annotations in a tier

Returns a list of all annotations in a tier
raw docstring

tier-as-datasetclj

(tier-as-dataset doc tier-id)

Converts tier from XML to a dataset representation.

Converts tier from XML to a dataset representation.
raw docstring

tier-cvclj

(tier-cv doc tier-id)

Returns the controlled vocabulary associated with a tier

Returns the controlled vocabulary associated with a tier
raw docstring

tier-cv-idclj

(tier-cv-id doc tier-id)

Returns the controlled vocabulary ID of a tier with a given ID

Returns the controlled vocabulary ID of a tier with a given ID
raw docstring

tier-cve-idclj

(tier-cve-id doc tier-id content)

Returns the controlled vocabulary entry ID associated with a particular content of a particular tier

Returns the controlled vocabulary entry ID associated with a particular content of a particular tier
raw docstring

tier-dataset->xmlclj

(tier-dataset->xml dataset tier-id type target-doc)

Converts a tier from a dataset to XML representation.

Converts a tier from a dataset to XML representation.
raw docstring

tier-idsclj

(tier-ids doc)

Returns all tier IDs in a document

Returns all tier IDs in a document
raw docstring

tier-summaryclj

(tier-summary doc tier-id)

Provides a summary of tier, including number of annotations and span of timings

Provides a summary of tier, including number of annotations and span of timings
raw docstring

tier-typeclj

(tier-type doc tier-id)

Returns the linguistic type ref of the tier with the target tier ID

Returns the linguistic type ref of the tier with the target tier ID
raw docstring

tier-with-time-values-as-datasetclj

(tier-with-time-values-as-dataset doc tier-id)

Gets tier with associated time values as as a dataset.

Gets tier with associated time values as as a dataset.
raw docstring

tiersclj

(tiers doc)

Returns all tiers in a document

Returns all tiers in a document
raw docstring

time-orderclj

(time-order doc)

Returns time order of document.

Returns time order of document.
raw docstring

time-order-as-datasetclj

(time-order-as-dataset doc)

Returns time order of document as dataset.

Returns time order of document as dataset.
raw docstring

time-order-dataset->xmlclj

(time-order-dataset->xml dataset)

time-slotclj

(time-slot doc time-slot-id)

Returns a time slot with target ID.

Returns a time slot with target ID.
raw docstring

time-slot-idsclj

(time-slot-ids doc)

Returns all time slot IDs in document.

Returns all time slot IDs in document.
raw docstring

time-slotsclj

(time-slots doc)

Returns a vector of all time slots in document.

Returns a vector of all time slots in document.
raw docstring

truncate-timeclj

(truncate-time time upper-limit)

Sets all time values above an upper limit equal to upper limit.

Sets all time values above an upper limit equal to upper limit.
raw docstring

unflatten-and-add-time-slotclj

(unflatten-and-add-time-slot doc tsID time)

Adds a time slot with a particular ID to document

Adds a time slot with a particular ID to document
raw docstring

unflatten-annotationclj

(unflatten-annotation {aID :ANNOTATION_ID
                       ts1 :TIME_SLOT_REF1
                       ts2 :TIME_SLOT_REF2
                       cve-ref :CVE_REF
                       c :content})
(unflatten-annotation aID ts1 ts2 content)
(unflatten-annotation aID ts1 ts2 cve-ref content)

Converts a flat representation of annotation to a nested XML representation.

Converts a flat representation of annotation to a nested XML representation.
raw docstring

unflatten-time-slotclj

(unflatten-time-slot {tsID :TIME_SLOT_ID time :TIME_VALUE})
(unflatten-time-slot tsID time)

Converts time slot from a flat map to an XML representation.

Converts time slot from a flat map to an XML representation.
raw docstring

update-annotation-idclj

(update-annotation-id annotation-id update-fn)

Updates an annotation ID with a given function applied to the number part of the ID.

Updates an annotation ID with a given function applied to the number part of the ID. 
raw docstring

update-time-slot-idclj

(update-time-slot-id time-slot-id update-fn)

Updates the numeric portion of a given time slot ID with an update-fn.

Updates the numeric portion of a given time slot ID with an update-fn.
raw docstring

validate-annotation-id!clj

(validate-annotation-id! doc annotation-id)

validate-cv-id!clj

(validate-cv-id! doc cv-id)

validate-linguistic-type-id!clj

(validate-linguistic-type-id! doc linguistic-type-id)

validate-tier-id!clj

(validate-tier-id! doc tier-id)

validate-time-slot-id!clj

(validate-time-slot-id! doc time-slot-id)

video-rel-urlclj

(video-rel-url doc)

Returns the relative path to the video

Returns the relative path to the video
raw docstring

video-urlclj

(video-url doc)

Returns the absolute path to the video

Returns the absolute path to the video
raw docstring

write-eafclj

(write-eaf doc filename)

Writes to an ELAN .eaf XML file

Writes to an ELAN .eaf XML file
raw docstring

xml-nodeclj

(xml-node tag attrs & content)

A generic function to generate an xml node.

A generic function to generate an xml node.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries