(add-annotation-to-tier doc tier-id new-annotation)Adds a new annotation to list of annotations of tier with given ID.
Adds a new annotation to list of annotations of tier with given ID.
(add-cv doc cv)Adds a new controlled vocabulary
Adds a new controlled vocabulary
(add-dataset-to-doc doc ds)Adds a dataset as annotations in an ELAN document.
Adds a dataset as annotations in an ELAN document.
(add-tier doc new-tier)Adds a new tier to document
Adds a new tier to document
(add-time-slot doc new-time-slot)Adds a time slot to document.
Adds a time slot to document.
(annotation doc annotation-id)Returns annotation with target ID.
Returns annotation with target ID.
(annotation-end-time-ref doc annotation-id)Returns the end time reference of annotation with a target ID.
Returns the end time reference of annotation with a target ID.
(annotation-ids doc)Returns a vector of all annotation IDs in documents
Returns a vector of all annotation IDs in documents
(annotation-start-time-ref doc annotation-id)Returns the start time reference of annotation with a target ID.
Returns the start time reference of annotation with a target ID.
(annotation-text doc annotation-id)Returns text of annotation with target ID.
Returns text of annotation with target ID.
(assert-is-annotation-id! annotation-id)(assert-is-time-slot-id! time-slot-id)Checks if input is formatted as a time slot.
Checks if input is formatted as a time slot.
(assign-agreement all agree disagree select-annotation-when-agree tau)Assigns agreement between two annotators by comparing subsequent entries in a dataset. The dataset should be the concatenation of the two annotator's datasets, ordered by time.
Assigns agreement between two annotators by comparing subsequent entries in a dataset. The dataset should be the concatenation of the two annotator's datasets, ordered by time.
(change-tier-type doc tier-id new-type)Changes the linguistic type ref of tier
Changes the linguistic type ref of tier
(copy-cv doc-from doc-to cv-id)Copies a controlled vocabulary with a given ID from one document to another
Copies a controlled vocabulary with a given ID from one document to another
(copy-tier-annotations doc-from tier-id-from doc-to tier-id-to)Copies all annotations of a tier with an ID tier-id-from from doc-from to tier in ID tier-id-to in doc-to.
Copies all annotations of a tier with an ID tier-id-from from doc-from to tier in ID tier-id-to in doc-to.
(copy-tier-between-files doc1 doc2 tier-id)Copy a tier with a given ID from one document to another
Copy a tier with a given ID from one document to another
(cv doc cv-id)Returns a controlled vocabulary by ID
Returns a controlled vocabulary by ID
(cv-ids doc)Returns all controlled vocabulary ids
Returns all controlled vocabulary ids
(cv-summary doc cv-id)Summarizes control vocabulary, including associated tiers and number of entries
Summarizes control vocabulary, including associated tiers and number of entries
(cv-vocab-with-ids doc cv-id)Returns a list of all controlled vocabulary entries and their associated unique identifiers
Returns a list of all controlled vocabulary entries and their associated unique identifiers
(cvs doc)Returns all controlled vocabularies
Returns all controlled vocabularies
(dataset-annotations-equal? annotation-1 annotation-2 tau)Checks if two annotations are equal, that is, with the same content and time intervals.
Checks if two annotations are equal, that is, with the same content and time intervals.
(doc-summary doc)Provides a summary of the document, including video file, controlled vocabularies, tiers, and number of annotations.
Provides a summary of the document, including video file, controlled vocabularies, tiers, and number of annotations.
(flatten-annotation annotation)Changes the XML representation of an annotation to a flat map.
Changes the XML representation of an annotation to a flat map.
(last-annotation-id doc)Returns the last annotation ID in the document
Returns the last annotation ID in the document
(last-time-slot-id doc)Returns last time slot ID in document.
Returns last time slot ID in document.
(linguistic-type doc linguistic-type-id)Returns a linguistic type with a given ID
Returns a linguistic type with a given ID
(linguistic-type-cv doc linguistic-type-id)Returns the controlled vocabulary id of a linguistic type with a given ID
Returns the controlled vocabulary id of a linguistic type with a given ID
(linguistic-type-ids doc)Returns all linguistic type IDs
Returns all linguistic type IDs
(linguistic-types doc)Returns all linguistic types
Returns all linguistic types
(media-descriptor doc)Returns the ELAN media descriptor
Returns the ELAN media descriptor
(read-eaf filename)Parses an ELAN .eaf XML file from the given filename into a standard Clojure structure.
Parses an ELAN .eaf XML file from the given filename into a standard Clojure structure.
(remove-annotation doc annotation-id)Removes annotation with target ID from document.
Removes annotation with target ID from document.
(remove-cv doc cv-id)Removes a controlled vocabulary by ID
Removes a controlled vocabulary by ID
(remove-tier doc tier-id)Removes tier from document
Removes tier from document
(remove-tier-annotations doc tier-id)Removes all annotations of a tier
Removes all annotations of a tier
(remove-time-slot doc time-slot-id)Removes a time slot with a given ID.
Removes a time slot with a given ID.
(rename-tier doc tier-id new-tier-id)Changes tier ID of a tier with a given tier ID
Changes tier ID of a tier with a given tier ID
(replace-annotation-end-time-ref doc annotation-id new-ref)Replaces the end time reference of annotation with a target ID.
Replaces the end time reference of annotation with a target ID.
(replace-annotation-id doc annotation-id new-id)Replaces annotation ID with a new ID
Replaces annotation ID with a new ID
(replace-annotation-start-time-ref doc annotation-id new-ref)Replaces the start time reference of annotation with a target ID.
Replaces the start time reference of annotation with a target ID.
(replace-annotation-text doc annotation-id new-text)Replaces the text of annotation with a target ID.
Replaces the text of annotation with a target ID.
(replace-prefix doc old-prefix new-prefix)Replaces all annotations with a give prefix with a new prefix.
Replaces all annotations with a give prefix with a new prefix.
(replace-tier doc tier-id new-tier)Replaces a tier with a given id with a new tier
Replaces a tier with a given id with a new tier
(replace-tier-annotations doc tier-id new-annotations)Replaces all annotations with a new list of annotations of a tier with a given ID
Replaces all annotations with a new list of annotations of a tier with a given ID
(replace-time-order doc new-time-order)Replaces time order of document with a new time order.
Replaces time order of document with a new time order.
(replace-time-slots doc new-time-slots)Replaces time slots in document with new time slots.
Replaces time slots in document with new time slots.
(replace-video-rel-url doc new-rel-url)Replaces the relative path to the video
Replaces the relative path to the video
(replace-video-url doc new-url)Replaces the absolute path to the video
Replaces the absolute path to the video
(same-intervals? t-start-1 t-end-1 t-start-2 t-end-2 tau)Checks if two intervals are equal within a tolerance tau.
Checks if two intervals are equal within a tolerance tau.
(selected-time-slots doc time-slot-ids)Returns all time slots that match a given vector of time slot IDs.
Returns all time slots that match a given vector of time slot IDs.
(tier doc tier-id)Returns a tier with a given tier ID
Returns a tier with a given tier ID
(tier-agreement doc1 doc2 tier-id tau)Compares the annotations of two annotators.
Compares the annotations of two annotators.
(tier-annotations doc tier-id)Returns a list of all annotations in a tier
Returns a list of all annotations in a tier
(tier-as-dataset doc tier-id)Converts tier from XML to a dataset representation.
Converts tier from XML to a dataset representation.
(tier-cv doc tier-id)Returns the controlled vocabulary associated with a tier
Returns the controlled vocabulary associated with a tier
(tier-cv-id doc tier-id)Returns the controlled vocabulary ID of a tier with a given ID
Returns the controlled vocabulary ID of a tier with a given ID
(tier-cve-id doc tier-id content)Returns the controlled vocabulary entry ID associated with a particular content of a particular tier
Returns the controlled vocabulary entry ID associated with a particular content of a particular tier
(tier-dataset->xml dataset tier-id type target-doc)Converts a tier from a dataset to XML representation.
Converts a tier from a dataset to XML representation.
(tier-ids doc)Returns all tier IDs in a document
Returns all tier IDs in a document
(tier-summary doc tier-id)Provides a summary of tier, including number of annotations and span of timings
Provides a summary of tier, including number of annotations and span of timings
(tier-type doc tier-id)Returns the linguistic type ref of the tier with the target tier ID
Returns the linguistic type ref of the tier with the target tier ID
(tier-with-time-values-as-dataset doc tier-id)Gets tier with associated time values as as a dataset.
Gets tier with associated time values as as a dataset.
(time-order doc)Returns time order of document.
Returns time order of document.
(time-order-as-dataset doc)Returns time order of document as dataset.
Returns time order of document as dataset.
(time-order-dataset->xml dataset)(time-slot doc time-slot-id)Returns a time slot with target ID.
Returns a time slot with target ID.
(time-slot-ids doc)Returns all time slot IDs in document.
Returns all time slot IDs in document.
(time-slots doc)Returns a vector of all time slots in document.
Returns a vector of all time slots in document.
(truncate-time time upper-limit)Sets all time values above an upper limit equal to upper limit.
Sets all time values above an upper limit equal to upper limit.
(unflatten-and-add-time-slot doc tsID time)Adds a time slot with a particular ID to document
Adds a time slot with a particular ID to document
(unflatten-annotation {aID :ANNOTATION_ID
ts1 :TIME_SLOT_REF1
ts2 :TIME_SLOT_REF2
cve-ref :CVE_REF
c :content})(unflatten-annotation aID ts1 ts2 content)(unflatten-annotation aID ts1 ts2 cve-ref content)Converts a flat representation of annotation to a nested XML representation.
Converts a flat representation of annotation to a nested XML representation.
(unflatten-time-slot {tsID :TIME_SLOT_ID time :TIME_VALUE})(unflatten-time-slot tsID time)Converts time slot from a flat map to an XML representation.
Converts time slot from a flat map to an XML representation.
(update-annotation-id annotation-id update-fn)Updates an annotation ID with a given function applied to the number part of the ID.
Updates an annotation ID with a given function applied to the number part of the ID.
(update-time-slot-id time-slot-id update-fn)Updates the numeric portion of a given time slot ID with an update-fn.
Updates the numeric portion of a given time slot ID with an update-fn.
(validate-annotation-id! doc annotation-id)(validate-cv-id! doc cv-id)(validate-linguistic-type-id! doc linguistic-type-id)(validate-tier-id! doc tier-id)(validate-time-slot-id! doc time-slot-id)(video-rel-url doc)Returns the relative path to the video
Returns the relative path to the video
(video-url doc)Returns the absolute path to the video
Returns the absolute path to the video
(write-eaf doc filename)Writes to an ELAN .eaf XML file
Writes to an ELAN .eaf XML file
(xml-node tag attrs & content)A generic function to generate an xml node.
A generic function to generate an xml node.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |